Option Explicit
'On Error Resume Next
'Install UCSFwpa Enterprise wireless profile
' Supported platforms:  Windows 7, Vista and XP with Service Pack  3
' Requires external tools: "zwlancfg.exe", "CertMgr.exe" (from the Windows Platform SDK), and HotFix installer for KB918997
' Requires external files:  Trusted root certificate file, Trusted intermidiate ca file, XML configuration files for XP and Vista

' create constants
Const cNetName = "UCSFwpa"
Const cLogFile = "UCSFwpa.log"
Const cRootStore = "root"
Const cIntStore = "CA"
Const cGoDate = "20111025"

' declare variants
Dim oShell, oUserEnv, oFSO, oFile
Dim iSPVer
Dim strDate
Dim sTempEnv, strComputer, sOS, sRootName, sRootFile, sInt1Name, sInt1File, sInt2Name, sInt2File
Dim bReRun

'define variants
bReRun = False
strComputer = "."
sRootName = "AddTrust External CA Root"
sRootFile = "AddTrustExternalCARoot.crt"
sInt1Name = "ucsfwpa.ucsf.edu"
sInt1File = "ucsfwpa.ucsf.edu.cer"
sInt2Name = "COMODO High-Assurance Secure Server CA"
sInt2File = "COMODOHigh-AssuranceSecureServerCA.crt"


'// Check date before running anything else
strDate = DatePart("yyyy",Date) & Right("0" & DatePart("m",Date), 2) & Right("0" & DatePart("d", Date), 2)

If strDate < cGoDate Then
    Wscript.Echo "You are running the script too early.  Try again on " + Right(Left(cGoDate,6),2) + "-" + Right(cGoDate,2) + "-" + Left(cGoDate,4)
    Wscript.Quit -5
End If


'instantiate global objects
Set oShell = WScript.CreateObject("WScript.Shell")
Set oFSO = CreateObject("Scripting.FileSystemObject")
sTempEnv = oShell.ExpandEnvironmentStrings("%TEMP%") & "\"
Set oFile = oFSO.CreateTextFile(sTempEnv & cLogFile,True)

fDetectOS sOS, iSPVer

If InStr(sOS, "Vista") > 0 Then
	fInstCert sRootName,sRootFile,cRootStore
	fInstCert sInt1Name,sInt1File,cIntStore
	fInstCert sInt2Name,sInt2File,cIntStore
	subImpVistaProfile
	ElseIf InStr(sOS, "Windows 7") > 0 Then
		fInstCert sRootName,sRootFile,cRootStore
		fInstCert sInt1Name,sInt1File,cIntStore
		fInstCert sInt2Name,sInt2File,cIntStore
		subImpVistaProfile
	ElseIf InStr(sOS, "XP") > 0 Then
		If iSPVer = 3 Then
			fInstCert sRootName,sRootFile,cRootStore
			fInstCert sInt1Name,sInt1File,cIntStore
			fInstCert sInt2Name,sInt2File,cIntStore
			subImpXPProfile
		Else
			oFile.WriteLine "Your operating system is not supported for use with this script."
			WScript.Quit -4
		End If
	Else
End If

oFile.close

'''''''''''''''''''''''''''''''''
''' begin environment cleanup '''
'''''''''''''''''''''''''''''''''
Set oFile = Nothing
Set oFSO = Nothing
Set oUserEnv = Nothing
Set oShell = Nothing
''''''''''''''''''''''''''''''''''
''''' end environment cleanup ''''
''''''''''''''''''''''''''''''''''

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Begin Function - Detect current OS
'
Function fDetectOS(sOS, iSPVer)
'Detect OS Function - detects OS Caption string and Service Pack integer from WMI WIN32_OperatingSystem.
'Expects to varibles passed, returns the full OS Caption String, and SP Major Version intger
	'Declare variables
	Dim colItems
	Dim objWMIService, objItem
	'Instantiate local objects/collections
	Set objWMIService = GetObject("winmgmts:\\" & strComputer & "\root\CIMV2") 
	Set colItems = objWMIService.ExecQuery("Select * from Win32_OperatingSystem")

	For Each objItem In colItems
	  sOS = objItem.Caption
	  oFile.WriteLine "Detected Operating System: " & sOS
	  iSPVer = CInt(objItem.ServicePackMajorVersion)
	  oFile.WriteLine "Detected Service Pack Version: " & iSPVer
	  oFile.WriteLine "Service Pack Minor Version: " & objItem.ServicePackMinorVersion
	Next
	
	'Clean local objects/variables
	Set objItem = Nothing
	Set colItems = Nothing
	Set objWMIService = Nothing
End Function
'
' End Function - Detect current OS
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''


'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Begin Function - Prompt for script re-run and exit
'
Function fReRun
	'On Error Resume Next
	WScript.Echo "Updates to your Operating System were required.  These updates were needed to enable support of UCSF wireless on your system.  Please reboot your computer, then run this tool again to complete the configuration of UCSF wireless on your computer."
	WScript.Quit -6
End Function
'
' End Function - Prompt for script re-run and exit
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Begin Function - Install Certificate
'
Function fInstCert(sSearchStr,sCertFile,sStore)
' Installs root or intermediate certificate named by variant "sCertFile" into the local machine store.  
'    Searches the store for string in variant "sSearchStr" first to see if the cert is already present.
' Requires:  certmgr.exe from the Windows Platform SDK (available with VS .NET or VS 2008 installations)
' Requires:  Equifax root CA cert file, variant "sSearchStr" which specifies the subject of the root cert, variant "sCertFile" which specifies the root CA cert file name.
' Requires:  sStore, a variant which must have the value "root" or "CA".  This specifies that the cert will be installed either as a trusted root CA (root) or trusted Intermediate (CA).
' Notes:  We use the "root" argument to certmgr.exe to install into the "Trusted Root Certificate Authorities".  
'		We also could use "ca" to install Intermediate Certificate Authorities.
'		In a previous version of this script we used "oShell.Run", but his returned unexpected results on the
'		Windows 7 platform... using .Exec now.
	
	Dim bCertPresent, bInstSuccess
	Dim oExec
	Dim sOut

	bCertPresent = false
	bInstSuccess = false
	
	set oExec = oShell.Exec("certmgr.exe -c -s -r localMachine " & sStore)

	Do Until oExec.StdOut.AtEndOfStream
		sOut = oExec.StdOut.ReadLine()
		if InStr(sOut, sSearchStr) Then
			'oFile.WriteLine sOut
			bCertPresent = true
		End If
	Loop

	if bCertPresent = false then
		oFile.WriteLine "Root Certificate for """ & sSearchStr & """needs to be installed.  Attempting install..."
		set oExec = oShell.Exec("certmgr.exe -add -c " & sCertFile & " -s -r localMachine " & sStore)
		Do Until oExec.StdOut.AtEndOfStream
			sOut = oExec.StdOut.ReadLine()
			if InStr(sOut, "Succeeded") Then
				'oFile.WriteLine sOut
				bInstSuccess = true
			End If
		Loop
		if bInstSuccess = true then
			oFile.WriteLine "Certificate installed successfully"
		else 
			oFile.WriteLine "Certificate failed to install... Please see the manual profile " _
			& "configuration instructions available at http://UCSFwpa.ucsf.edu/  A " _
			& "log file named " & cLogFile & " which contains the full error message can be " _
			& "found in the " & sTempEnv & " directory."
			WScript.Quit -2
		end if
	else
		oFile.WriteLine "Root Certificate for """ & sSearchStr & """ is already installed."
	End If
	
End Function
'
' End Function - Install Certificate
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Begin Subroutine - Install Vista Wireless Profile
'
Sub subImpVistaProfile
'Imports Vista Wireless Profile using NETSH command.  
'Requires: a Vista wifi profile file exported using NETSH, defined in cVistaProfile within this function
	'On Error Resume Next
	Const cVistaProfile = ".\UCSFwpa.xml"
	Const cUserScope = "all"
	
	Dim iStrMatch
	Dim oExec, oStdOut
	Dim sStdOutLine
	
	oFile.WriteLine "Executing command: netsh wlan add profile filename=""" & cVistaProfile & """ user=" & cUserScope & ""
	Set oExec = oShell.Exec("netsh wlan add profile filename=""" & cVistaProfile & """ user=" & cUserScope & "")
	Set oStdOut = oExec.stdOut
	While Not oStdOut.AtEndOfStream
		sStdOutLine = oStdOut.ReadLine
		oFile.WriteLine(sStdOutLine)
		iStrMatch = CInt(InStr(sStdOutLine, "Profile " & cNetName & " is added on interface"))
		If iStrMatch > 0 Then
			WScript.Echo "The " & cNetName & " wireless profile was added successfully to your system"
		ElseIf iStrMatch = 0 Then
			WScript.Echo "The wireless profile failed to import.  Please see the manual profile " _
			& "configuration instructions available at http://UCSFwpa.ucsf.edu  A " _
			& "log file named " & cLogFile & " which contains the full error message can be " _
			& "found in the " & sTempEnv & " directory."
			WScript.Quit -3
		End If
	Wend
	
	Set oStdOut = Nothing
	Set oExec = Nothing
End Sub	
'
' End Subroutine - Install Vista Wireless Profile
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Begin Subroutine - Install XP Wireless Profile
'
Sub subImpXPProfile
' Installs an XP wifi profile using zwlancfg.exe.  
' Requires the HotFix KB918997 be installed on the system before running.
' Requires presence of xml wifi profile file defined in cXPProfile
' Required global oFSO FileSystemObject.
	'On Error Resume Next
	Const cXPProfile = ".\UCSFwpa-XP.xml"
	Const cForReading = 1
	Dim iStrMatch
	Dim oZFile
	Dim sZFile
	
	oFile.WriteLine "Executing command: zwlancfg.exe /import:""" & cXPProfile & """ /log"
	oShell.Run "zwlancfg.exe /import:""" & cXPProfile & """ /log", 1, True
	
	Set oZFile = oFSO.OpenTextFile("zwlancfg.log", cForReading)
	sZFile = oZFile.ReadAll
	oZFile.close
	
	oFile.WriteLine "Output from zwlancfg.exe follows..."
	oFile.Write sZFile
	
	iStrMatch = CInt(InStr(sZFile, "Profile added to interface"))
	If iStrMatch > 0 Then
		WScript.Echo "The " & cNetName & " wireless profile was added successfully to your system"
	Else WScript.Echo "Import of the UCSFwpa profile for XP failed.  Please see the manual profile " _
		& "configuration instructions available at " _
		& "http://UCSFwpa.ucsf.edu  A log file named " & cLogFile & " which " _
		& "contains the full error message can be found in the " & sTempEnv & " directory."
		WScript.Quit -1
	End If
End Sub
'
' End Subroutine - Install XP Wireless Profile
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''